@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Proch::Cmd;
 
-$Proch::Cmd::VERSION = 0.001;
+$Proch::Cmd::VERSION = 0.002;
 # ABSTRACT: Execute shell commands controlling inputs and outputs
 
 
@@ -279,11 +279,7 @@ Proch::Cmd - Execute shell commands controlling inputs and outputs
 
 =head1 VERSION
 
-version 0.001
-
-=head1 SYNOPSIS
-
-  ...
+version 0.002
 
 =head1 NAME
 
@@ -291,17 +287,52 @@ Proch::Cmd - a simple library to execute shell commands
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 METHODS
 
-=head2 method_x
+=head2 new()
 
-This method does something experimental.
+The method creates a new shell command object, with the followin properties:
 
-=head2 method_y
+=item U<command> [required]
 
-This method returns a reason.
+The shell command to execute
+
+=item U<workingdir> (default: /tmp) [important]
+
+Command temporary directory, should be the pipeline output directory, can be 
+omitted for minor commands like 'mkdir', but should be set for pipeline steps.
+
+=item U<description>
+
+Optional description of the command, for log and verbose mode
+
+=item U<input_files> (array)
+
+A list of files that must exist and be not empty before command execution
+
+=item U<output_files> (array)
+
+A list of files that must exist and be not empty after command execution
+
+=item U<die_on_error> (default: 1)
+
+If command returns non zero value, die (default behaviour)
+
+=item U<verbose>
+
+Enable verbose execution
+
+=item U<no_cache>
+
+Don't skip command execution if the command was already executed
+
+=back
+
+=head2 simplerun()
+
+Executes the shell command returning an object
 
 =head1 AUTHOR
 
